@@ -1,10 +1,10 @@
-__version__ = "0.1.9"
+__version__ = "0.1.10"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "wiggin15@yahoo.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '38f978e48826f968c3c95838cb75c0e9204ebb59'
-__git_head_subject__ = 'Finished release v0.1.9.'
+__git_head_hash__ = '72e486daa0dd332dd7ee63bf4bc2ed4683d44ca5'
+__git_head_subject__ = 'empty commit after version v0.1.9'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
